@@ -47,7 +47,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             skipSystemCheck = parser.getboolean('options', 'skipSystemCheck')
             print skipSystemCheck
             
-        self.sshSystemStart = False
+        sshSystemStart = False
         sshSystemRespawn = False
         if path.isfile("/etc/event.d/sshd"):
             sshFile = open("/etc/event.d/sshd",'r')
